@@ -9,7 +9,8 @@
 #' str_length(letters)
 #' str_length(c("i", "like", "programming", NA))
 str_length <- function(string) {
-  string <- as.character(string)
+  string <- check_string(string)
+
   nc <- nchar(string)
   is.na(nc) <- is.na(string)
   nc
