@@ -6,7 +6,7 @@ context("Test padding")
 test_that("long strings are unchanged", {
   lengths <- sample(40:100, 10)
   strings <- laply(lengths, function(x) 
-    str_join(letters[sample(26, x, rep = T)], collapse = ""))
+    str_c(letters[sample(26, x, rep = T)], collapse = ""))
   
   padded <- str_pad(strings, width = 30)
   expect_that(str_length(padded), equals(str_length(padded)))
